const assert = require('assert');
const ScriptModule = require(__dirname + "/../engine/script");
const nlp = require(__dirname + "/nlp").nlp;

describe("bot", ()=>{
    let script = new ScriptModule.Script();
    options = {
        homedir : __dirname,
        uid : "50d122fd3204e67f3a6452ba28b522da",
        data : {
            text : "What is your name?"
        },
        env : {
            DATABASE_URI : "recime"
        }
    };
    describe("execute", ()=>{
        it("should assert callback", (done)=>{
            script.execute(options).then((data)=>{
                assert.equal(data.text, "Hello! I am Turing Bot, How may I help?");
                done();
            }, (err)=>{
                assert.ok(false)
            });
        });
        it("should assert env", (done)=>{
            script.execute(options).then((data)=>{
                assert.equal(data.env.DATABASE_URI, "recime");
                done();
            }, (err)=>{
               assert.ok(false)
            });
        });
        it("should validate platform flag", (done)=>{
            options['platform'] = 'telegram';
            script.execute(options).then((data)=>{
                assert.equal(data.platform, "telegram");
                done();
            }, (err)=>{
                assert.ok(false)
            });
        });
        it("should handle exceptions", (done)=>{
            var options = { 
              homedir : __dirname,
              uid : "106ac42c537870651803235daa6f41e7"
            };
            script.execute(options).then((data)=>{
               assert.ok(false);
                done();
            }, (err)=>{
                 assert.equal(err.message, "Cannot read property \'text\' of undefined");
                 assert.ok(true);
                 done();
            });
        });
        it("should execute external plugin", (done)=>{
            options['platform'] = 'wechat';
           
            script.execute(options).then((data)=>{
                assert.ok(false);
                done();
            }, (err)=>{
                assert.equal(err.message, "Plugin is not configured.");
                assert.ok(true);
                done();
            });
        });
        // it("should handle timeout", (done)=>{
        //     options['platform'] = 'facebook';
        //     script.execute(options).then((data)=>{
        //         assert.ok(false);
        //         done();
        //     }, (err)=>{
        //         assert.equal(err.message, "The Bot is taking too long to respond (>10s).");
        //         assert.ok(true);
        //         done();
        //     });
        // }).timeout(11 * 1000);
    });
});
